@@ -178,13 +178,16 @@ task_item_set_visibility (TaskItem *item)
   
   if (!wnck_window_is_skip_tasklist (window))
   {
-    if (wnck_workspace_is_virtual (workspace))
+    if (workspace != NULL)
     {
-      show_window = wnck_window_is_in_viewport (window, workspace);
-    }
-    else
-    {
-      show_window = wnck_window_is_on_workspace (window, workspace);
+      if (wnck_workspace_is_virtual (workspace))
+      {
+        show_window = wnck_window_is_in_viewport (window, workspace);
+      }
+      else
+      {
+        show_window = wnck_window_is_on_workspace (window, workspace);
+      }
     }
     show_window = show_window || show_all;
   }
@@ -279,15 +282,13 @@ task_item_sized_pixbuf_for_window (TaskItem   *item,
 static gboolean
 #if GTK_CHECK_VERSION (3, 0, 0)
 task_item_draw (GtkWidget      *widget,
-		        cairo_t *cr)
+		        cairo_t *unused)
 #else
 task_item_expose_event (GtkWidget      *widget,
 		        GdkEventExpose *event)
 #endif
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
   cairo_t *cr;
-#endif
   TaskItem *item;
   GdkRectangle area;
   TaskItemPrivate *priv;
@@ -305,7 +306,9 @@ task_item_expose_event (GtkWidget      *widget,
   g_return_val_if_fail (WNCK_IS_WINDOW (priv->window), FALSE);
   
   area = priv->area;
-#if !GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION (3, 0, 0)
+  cr = gdk_cairo_create (gtk_widget_get_window (widget));
+#else
   cr = gdk_cairo_create (event->window);
 #endif
   
@@ -413,9 +416,7 @@ task_item_expose_event (GtkWidget      *widget,
     cairo_paint_with_alpha (cr, .65);
   }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
   cairo_destroy (cr);
-#endif
   
   return FALSE;
 }
